translate.filters.pofilter.FilterOptionParser

Package translate :: Package filters :: Module pofilter :: Class FilterOptionParser |
[hide private]
[frames] | no frames]

# Class FilterOptionParser

source code

a specialized Option Parser for filter tools...

Instance Methods | [hide private]
__init__(self, formats) construct the specialized Option Parser | source code
parse_noinput(self, option, opt, value, parser, *args, **kwargs) this sets an option to true, but also sets input to - to prevent an error | source code
run(self) parses the arguments, and runs recursiveprocess with the resulting options | source code
Inherited from `misc.optrecurse.RecursiveOptionParser`: `checkoutputsubdir`, `define_option`, `finalizetempoutputfile`, `format_manpage`, `get_prog_name`, `getformathelp`, `getfullinputpath`, `getfulloutputpath`, `getfulltemplatepath`, `getoutputname`, `getoutputoptions`, `getpassthroughoptions`, `gettemplatename`, `getusageman`, `getusagestring`, `initprogressbar`, `isexcluded`, `isrecursive`, `isvalidinputname`, `mkdir`, `openinputfile`, `openoutputfile`, `opentemplatefile`, `opentempoutputfile`, `parse_args`, `print_manpage`, `processfile`, `recurseinputfilelist`, `recurseinputfiles`, `recursiveprocess`, `reportprogress`, `set_usage`, `seterrorleveloptions`, `setformats`, `setmanpageoption`, `setprogressoptions`, `setpsycooption`, `splitext`, `splitinputext`, `splittemplateext`, `templateexists`, `usepsyco`, `warning` Inherited from `optparse.OptionParser`: `add_option_group`, `check_values`, `destroy`, `disable_interspersed_args`, `enable_interspersed_args`, `error`, `exit`, `expand_prog_name`, `format_epilog`, `format_help`, `format_option_help`, `get_default_values`, `get_description`, `get_option_group`, `get_usage`, `get_version`, `print_help`, `print_usage`, `print_version`, `set_default`, `set_defaults`, `set_process_default_values` Inherited from `optparse.OptionParser` (private): `_add_help_option`, `_add_version_option`, `_create_option_list`, `_get_all_options`, `_get_args`, `_get_encoding`, `_init_parsing_state`, `_match_long_opt`, `_populate_option_list`, `_process_args`, `_process_long_opt`, `_process_short_opts` Inherited from `optparse.OptionContainer`: `add_option`, `add_options`, `format_description`, `get_option`, `has_option`, `remove_option`, `set_conflict_handler`, `set_description` Inherited from `optparse.OptionContainer` (private): `_check_conflict`, `_create_option_mappings`, `_share_option_mappings` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `optparse.OptionParser`: `standard_option_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, formats) (Constructor) | source code
construct the specialized Option Parser Parameters: `formats` - See setformats() for an explanation of the formats parameter. Overrides: object.__init__

### run(self) | source code
parses the arguments, and runs recursiveprocess with the resulting options Overrides: misc.optrecurse.RecursiveOptionParser.run